import {csv, 
        select,
        scaleLinear,
        scalePoint,
        max,
        axisLeft,
        axisBottom,
        format,
        nice
       } from 'd3'

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const xValue = d => d.population;
const yValue = d => d.country;

const margin = {top: 50, right: 20, bottom: 80, left:180};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const render = data => {
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  	.nice();
  
  const xAxis = 
        	axisBottom(xScale)
  					.tickFormat(format('.3s'))
  					.tickSize(-innerHeight)
  					.tickPadding(20);
  					
 
  const yScale = scalePoint()
		.domain(data.map(yValue))
  	.range([0, innerHeight]);
  	
	
  const yAxis = 
        	axisLeft(yScale)
  				.tickSize(-innerWidth);
  				
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  const yAxisG = g.append('g').call(yAxis);
  	
  
  yAxisG
  	.select('.domain')
  		.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerHeight})`);
  
  xAxisG
  	.select('.domain')
  		.remove();
  
  xAxisG
    .append('text')
  		.attr('y', 70)
      .attr('x', innerWidth / 2)
  		.style('fill','black')
  		.text('Population');
  		
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
    	.attr('r', 10);
  
  g.append('text')
  	.attr('y', -10)
  	.attr('x', innerWidth / 4)
  	.text('Top 10 Country');
  		
  		

}

csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population;
  })
  render(data);
})